# 1.0 **Composition Features**

## 1.1 REQ003

Doorstop **shall** provide unique and permanent identifiers to linkable sections of text.

## 1.2 REQ004

Doorstop **shall** support formatting within linkable text.

## 1.3 REQ001

Doorstop **shall** support the storage of external requirements assets.

# 2.0 **Presentation Features**

## 2.1 REQ007

Doorstop **shall** provide a way to view requirements as a document.

## 2.2 REQ008

Doorstop **shall** provide a way to view document items interactively.

## 2.3 REQ009

Doorstop **shall** provide the capability to baseline versions of requirements.

# 3.0 **Administration Features**

## 3.1 REQ011

Doorstop **shall** store requirements in a permanent and secure manner.

## 3.2 REQ012

Doorstop **shall** handle change management of the requirements.

## 3.3 REQ013

Doorstop **shall** associate requirements changes to existing developer identification.

## 3.4 REQ014

Doorstop **shall** be scalable to support thousands of requirements.

## 3.5 REQ015

Doorstop **shall** provide a lightweight installation method.

